#include <stdlib.h>
#include <stdio.h>
#include <stdbool.h>
#include <unistd.h>
#include <math.h>

#include <SDL.h>
#include <SDL_ttf.h>
#include <SDL_image.h>

#include "slime.h"
#include "menu.h"
#include "jeu.h"
#include "config.h"
#include "sndserver.h"

#ifdef WINDOWS
	#define CONFIG_FICH "config.slm"
#else
	#define CONFIG_FICH ".slime"
#endif

/*
This file is part of Slime Volley.

	Slime Volley is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Slime Volley is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Slime Volley.  If not, see <http://www.gnu.org/licenses/>.

Copyright (c) MCMic, VinDuv.

$Id: slime.c 72 2008-01-20 14:51:59Z vinduv $
*/

extern struct SoundBank sndbank;

void LoadSound( char* datadir)
{
	char file[128];

	if( OpenSound() < 0)
	{
		printf( "Couldn't open audio: %s\n", SDL_GetError());
	}
	else
	{

/*		sprintf( file, "sound/boing01.wav");*/
		sprintf( file, "sound/hitball.wav");
		printf( "Loading %s... ", file);
		sndbank.collision_balle_filet = AddSoundFile( file); 
		if( sndbank.collision_balle_slime  < 0)
			printf( "failed: %s\n", SDL_GetError());
		else
			printf( "done\n");
	
		sprintf( file, "sound/boing01.wav");
		printf( "Loading %s... ", file);
		sndbank.collision_balle_filet = AddSoundFile( file); 
		
		if( sndbank.collision_balle_filet < 0)
			printf( "failed: %s\n", SDL_GetError());
		else
			printf( "done\n");

			
		SDL_PauseAudio(0);
	}
}
	 

int main(int argc, char* argv[]) {
	char *datadir, *conf_fich;

	#ifdef WINDOWS
		conf_fich = malloc(255 * sizeof(*conf_fich));
	#endif

	// Configuration du clavier

	FILE* touches_fich;

	touches_jg = (touches_joueur*) malloc(sizeof(touches_joueur));
	touches_jd = (touches_joueur*) malloc(sizeof(touches_joueur));

	if(getenv("HOME") != NULL) {
		#ifdef WINDOWS
			sprintf(conf_fich, "%s/"CONFIG_FICH, getenv("HOME")); // Le fichier sera lu/écrit depuis ~
		#else
			asprintf(&conf_fich, "%s/"CONFIG_FICH, getenv("HOME")); // Le fichier sera lu/écrit depuis ~
		#endif
	} else {
		conf_fich = CONFIG_FICH; // Le fichier sera lu/écrit depuis le répertoire courant
	}

	touches_fich = fopen(conf_fich, "rb");

	if(touches_fich != NULL) {
		if(fread(touches_jg, sizeof(touches_joueur), 1, touches_fich) < 0) {
			touches_jg->haut	= SDLK_z;
			touches_jg->bas		= SDLK_s;
			touches_jg->gauche	= SDLK_q;
			touches_jg->droite	= SDLK_d;
		}
		
		if(fread(touches_jd, sizeof(touches_joueur), 1, touches_fich) < 0) {
			touches_jd->haut	= SDLK_UP;
			touches_jd->bas		= SDLK_DOWN;
			touches_jd->gauche	= SDLK_LEFT;
			touches_jd->droite	= SDLK_RIGHT;
		}
		fclose(touches_fich);
	} else {
		touches_jg->haut	= SDLK_z;
		touches_jg->bas		= SDLK_s;
		touches_jg->gauche	= SDLK_q;
		touches_jg->droite	= SDLK_d;
		touches_jd->haut	= SDLK_UP;
		touches_jd->bas		= SDLK_DOWN;
		touches_jd->gauche	= SDLK_LEFT;
		touches_jd->droite	= SDLK_RIGHT;
	}

	touches_fich = fopen(conf_fich, "wb");
	if(touches_fich == NULL) {
		perror("fopen: "CONFIG_FICH);
		fflush(stderr);
	}
	
	if(getenv("SLIME_DATADIR") != NULL) {
		datadir = getenv("SLIME_DATADIR");
		
	} else if(access("data/menu.png", F_OK) == 0) {
		datadir = "data";
		
	} else if(access("../data/menu.png", F_OK) == 0) {
		datadir = "../data";
	} else {
		datadir = DATA_DIR;
	}


	// Gestion de SDL
	if(chdir(datadir) < 0) {
		fprintf(stderr, "Impossible d'accéder aux données de jeu dans %s.\n", datadir);
		perror("chdir: data");
		exit(EXIT_FAILURE);
	}

	SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO);
	SDL_WM_SetIcon(IMG_Load("icone.tiff"), NULL);
	ecran = SDL_SetVideoMode(LARG_ECRAN, HAUT_ECRAN, 32, SDL_HWSURFACE | SDL_DOUBLEBUF); // + " | SDL_FULLSCREEN" pour plein écran.
	// Test du mode plein écran: sous linux ça fait une bande noire autour du jeu, sans aucun doute pour avoir une résolution standard.(mais ça marche)
	SDL_WM_SetCaption("Slime", "Slime");
	SDL_ShowCursor(SDL_DISABLE);
	
	TTF_Init();	
	police = TTF_OpenFont("angelina.ttf", 30);
	if(police == NULL) {
		perror("TTF_OpenFont: angelina.ttf");
		exit(-1);
	}


	/* chargement des bruitages utilisées */
	LoadSound(datadir);

	menu();

	if(!quitter) { // L'utilisateur n'a pas demandé à quitter
		jeu();
	}

	CloseSound();


	SDL_FreeSurface(ecran);
	free(police);

	SDL_Quit();
		
	fwrite(touches_jg, sizeof(touches_joueur), 1, touches_fich);
	fwrite(touches_jd, sizeof(touches_joueur), 1, touches_fich);
	fclose(touches_fich);

	exit(EXIT_SUCCESS);
}


